@@ -284,9 +284,6 @@ def create_schema(d, title, descr, required_keys=None):
         List of strings of the keys that are required in the schema
     """
     def get_property(key, dat, prop={}):
-        print(f"KEY: {key}")
-        print(f"DAT: {dat}")
-        # print(f"RETURN: {key}")
         try:
             dtype = py_type_to_schema_type[type(dat)]
         except:
@@ -300,11 +297,8 @@ def create_schema(d, title, descr, required_keys=None):
                 }
             }
         elif dtype == "object":
-            # item_type = py_type_to_schema_type[type(dat[key])]
-            # if item_type == "object":
             props = {}
             for k in dat:
-                print(k)
                 props[k] = get_property(k, dat[k])
             return {
                 "type": "object",
@@ -315,7 +309,6 @@ def create_schema(d, title, descr, required_keys=None):
             return {
                 "type": dtype
             }
-        
     schema = {
         "$schema": f"http://merf.egs.anl.gov/mdml-{title}-auto-schema#",
         "title": title,
